h1{font-weight:300}h2,h3{font-weight:300}.resource-description,.response-info{margin-bottom:2em}.version:before{content:"v";opacity:.6;padding-right:.25em}.version{font-size:70%}.format-option{font-family:Menlo,Consolas,"Andale Mono","Lucida Console",monospace}.button-form{float:right;margin-right:1em}td.nested{padding:0 !important}td.nested>table{margin:0}form select,form input,form textarea{width:90%}form select[multiple]{height:150px}.disabled-tooltip-shield{position:absolute;top:0;right:0;bottom:0;left:0}.errorlist{margin-top:.5em}pre{overflow:auto;word-wrap:normal;white-space:pre;font-size:12px}.page-header{border-bottom:0;padding-bottom:0}#filtersModal form input[type=submit]{width:auto}#filtersModal .modal-body h2{margin-top:0}