html,body{height:100%}body{background:#fff;padding:0;margin:0;font-family:'Source Sans Pro',sans-serif;color:#2f2f2f}.clearfix1:before{content:"";display:table;clear:both}.clearfix2:after{content:"";display:table;clear:both}ul,ol{margin:0;padding:0;list-style:none}ul li,ol li{margin:0;padding:0}h1,h2,h3,h4,h5,h6,p{margin:0;padding:0}h1{margin-left:-2px}a,a:hover,a:visited,a:focus{text-decoration:none}*{box-sizing:border-box}h1{font-family:"Circe";font-size:36px;font-weight:normal;font-style:normal;font-stretch:normal;line-height:1.22;letter-spacing:-.3px;margin-bottom:10px}h2{font-family:'Source Sans Pro',sans-serif;font-size:30px;font-weight:normal;font-style:normal;font-stretch:normal;line-height:normal;letter-spacing:-.3px;margin-bottom:10px}h3{font-family:"Circe";font-size:24px;font-weight:normal;font-style:normal;font-stretch:normal;line-height:normal;letter-spacing:-.3px;margin-bottom:10px}.mobile-index{background-image:linear-gradient(7deg,#f6f8fb,#eaeef5);min-height:100vh;height:auto;width:100%;text-align:center;padding:20px 25px}.mobile-index-header{display:block;height:38px;width:100%;background-position:center left;background-repeat:no-repeat;background-size:contain;max-width:750px;margin:0 auto}.mobile-index-body-doctor{height:calc(100% - 305px);background:url(ansible-logo.png) no-repeat center / contain}.mobile-index-body-inner{max-width:750px;margin:0 auto}.mobile-index-body-inner h1{font-family:'Source Sans Pro',sans-serif;font-size:100px;font-weight:normal;font-style:normal;font-stretch:normal;line-height:1.3;letter-spacing:-.2px;text-align:center;color:#575757;margin-bottom:20px}.mobile-index-body-inner h2{font-family:'Source Sans Pro',sans-serif;font-size:26px;font-weight:normal;font-style:normal;font-stretch:normal;line-height:1.3;letter-spacing:-.2px;text-align:center;color:#575757;margin-bottom:20px}@media(max-width:480px){.mobile-index-body-inner h1{font-size:64px}}.mobile-index-body-inner form{height:202px}.mobile-index-body-inner form input{display:block;width:100%;height:58px;padding:0 32px;font-family:'Source Sans Pro',sans-serif;font-size:23px;font-weight:normal;font-style:normal;font-stretch:normal;letter-spacing:.6px;color:#4f4f4f;background-color:#fff;border:solid 1px #9dacce;margin-bottom:7px;outline:0}.mobile-index-body-inner form button{height:58px;background-color:#4a90e2;box-shadow:0 10px 17px 0 rgba(74,143,226,0.33);font-family:'Source Sans Pro',sans-serif;font-size:23px;font-weight:normal;font-style:normal;font-stretch:normal;letter-spacing:.6px;color:#fff;display:block;width:100%;border:0;outline:0}.mobile-index-body-inner form button:hover{background-color:#105d9f}.mobile-index-body-afterform{width:100%;text-align:justify}.mobile-index-body-afterform:after{content:"";display:inline-block;width:100%}.mobile-index-body-afterform a{font-family:"Circe";font-size:17px;font-weight:normal;font-style:normal;font-stretch:normal;line-height:normal;letter-spacing:normal;color:#3d7bc4;display:inline-block}h1{max-width:850px}.logo-img{width:50%;margin-bottom:20px;margin-top:12vh}@media(max-width:480px){.logo-img{width:80%;margin-top:8vh}}@media(max-width:320px){.logo-img{margin-top:0vh}}