# -*- coding: utf-8 -*-
# Generated by Django 1.11.15 on 2018-12-13 00:36
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('main', '0003_models_optimization'),
    ]

    operations = [
        migrations.CreateModel(
            name='ProjectTemplate',
            fields=[
                ('id', models.IntegerField(primary_key=True, serialize=False)),
                ('name', models.CharField(max_length=1024)),
                ('description', models.TextField()),
                ('repository', models.CharField(max_length=2048)),
                ('type', models.CharField(choices=[('GIT', 'GIT'), ('TAR', 'TAR')], max_length=256)),
                ('repo_auth', models.CharField(choices=[('NONE', 'NONE'), ('KEY', 'KEY'), ('PASSWORD', 'PASSWORD')], max_length=256)),
                ('auth_data', models.TextField()),
            ],
            options={
                'managed': False,
            },
        ),
    ]
