.highlight pre{background-color:#f7f7f9}.highlight pre p{color:#333}.highlight .mi{color:#208050}.highlight .s2{color:#D14}.highlight .kc{color:#000081}.highlight .nf,.highlight .na{font-weight:bold}.highlight .l,.highlight .nn,.highlight .kr,.highlight .m{color:#195f91}