.history-stdout{background-color:#000;color:#ececec;font-weight:bold;white-space:pre-wrap}.ansi-black-fg{color:#000}.ansi-red-fg{color:#ff6060}.ansi-green-fg{color:#60ff60}.ansi-yellow-fg{color:#ffff36}.ansi-blue-fg{color:#6060ff}.ansi-magenta-fg{color:#ff36ff}.ansi-cyan-fg{color:#36ffff}.ansi-white-fg{color:#ececec}.ansi-bright-black-fg{color:#363636}.ansi-bright-red-fg{color:#ff8080}.ansi-bright-green-fg{color:#80ff80}.ansi-bright-yellow-fg{color:#ffff80}.ansi-bright-blue-fg{color:#8080ff}.ansi-bright-magenta-fg{color:#ff80ff}.ansi-bright-cyan-fg{color:#80ffff}.ansi-bright-white-fg{color:#fff}.ansi-black-bg{background-color:#000}.ansi-red-bg{background-color:#ff6060}.ansi-green-bg{background-color:#60ff60}.ansi-yellow-bg{background-color:#ffff36}.ansi-blue-bg{background-color:#6060ff}.ansi-magenta-bg{background-color:#ff36ff}.ansi-cyan-bg{background-color:#36ffff}.ansi-white-bg{background-color:#ececec}.ansi-bright-black-bg{background-color:#363636}.ansi-bright-red-bg{background-color:#ff8080}.ansi-bright-green-bg{background-color:#80ff80}.ansi-bright-yellow-bg{background-color:#ffff80}.ansi-bright-blue-bg{background-color:#8080ff}.ansi-bright-magenta-bg{background-color:#ff80ff}.ansi-bright-cyan-bg{background-color:#80ffff}.ansi-bright-white-bg{background-color:#fff}